==> pinball_0.3.20201218.orig.tar.gz: pinball-0.3.20201218/README.md <==
# EMILIA PINBALL #

[![GitHub forks](
https://img.shields.io/github/forks/rzr/pinball.svg?style=social&label=Fork&maxAge=2592000
)](
https://GitHub.com/rzr/pinball/network/
)
[![license](
https://img.shields.io/badge/license-GPL-2.svg
)](GPL-2)
[![Build Status](
https://travis-ci.org/rzr/pinball.svg?branch=master
)](
https://travis-ci.org/rzr/pinball
)
[![IRC Channel](
https://img.shields.io/badge/chat-on%20freenode-brightgreen.svg
)](
https://kiwiirc.com/client/irc.freenode.net/#iot
)
[![Fediverse](
https://img.shields.io/mastodon/follow/279303?domain=https%3A%2F%2Fmastodon.social&style=social
)](
https://mastodon.social/@rzr/103448015175182101#:pinball:
)

## INTRODUCTION ##

Emilia Pinball is a libre pinball game simulator for GNU/Linux.

It can be played on a regular computer or a DiY pincab device.

[![pinball-video](
https://raw.githubusercontent.com/rzr/pinball/master/extra/files/screenshot.png
)](
http://pinball.sf.net
"pinball")

More more details check [FAQ](FAQ.md), [BUILD](BUILD.md), [CONTRIBUTING](CONTRIBUTING.md)
or linked resources from:

* <http://pinball.sourceforge.net/>

Send bug reports (after reading faq) and comments to

* <https://sourceforge.net/projects/pinball/>

For latest updates subscribe:

* <https://purl.org/rzr/pinball>

## USAGE ##

Controls:

* Back / Menu : Esc key
* Launch ball : Enter key or mouse's middle button
* Reset game : R key
* Left/Right Flipper : Left/Right Shift key  or mouse's left/right button
* Nudge from left/right : Left/Right Control key (or mouse's left/right + middle buttons)
* Nudge: Space key (or mouse's left+right+middle buttons)


## DEMO ##

[![pinball-video](
https://diode.zone/lazy-static/previews/b764fc94-b455-45f5-a62a-24ec6131112e.jpg
)](
https://rzr.github.io/rzr-presentations/docs/pinball/#/13
"pinball")

Watch video at:

* <https://peertube.debian.social/videos/watch/c23f0709-4099-4302-b877-f7d2562b2880?start=11m26s#:my-diy-pinball-on-debian-2020-rzr>

## RESOURCES ##

* <http://pinball.sf.net/>
* <https://purl.org/rzr/pinball>
* <https://github.com/rzr/pinball/>
* <https://purl.org/rzr/presentations>
* <https://purl.org/rzr>
* <https://rzr.github.io/rzr-presentations/docs/pinball/>
* <https://mdco2.mini.debconf.org/talks/23-my-diy-pinball-on-debian/>
* <https://peertube.debian.social/videos/watch/c23f0709-4099-4302-b877-f7d2562b2880#my-diy-pinball-on-debian>
* <https://github.com/rzr/pinball-table-gnu/>
* <https://github.com/rzr/pinball-table-hurd/>
* <https://packages.qa.debian.org/p/pinball.html>
* <https://libregamewiki.org/Emilia_Pinball>
* <http://rzr.online.fr/game.htm>
* <https://pdb.finkproject.org/pdb/package.php/pinball>
* <https://aur.archlinux.org/packages/pinball/>
* <https://www.pincabpassion.net/t12916-wip-pincab-libre-sous-gnu-linux-avec-emilia-pinball#210037>

==> pinball_0.3.20230219.orig.tar.gz: pinball-0.3.20230219/README.md <==
# EMILIA PINBALL #

[![GitHub forks](
https://img.shields.io/github/forks/rzr/pinball.svg?style=social&label=Fork&maxAge=2592000
)](
https://GitHub.com/rzr/pinball/network/
)
[![license](
https://img.shields.io/badge/license-GPL-2.svg
)](GPL-2)
[![Build Status](
https://travis-ci.org/rzr/pinball.svg?branch=master
)](
https://travis-ci.org/rzr/pinball
)
[![Fediverse](
https://img.shields.io/mastodon/follow/279303?domain=https%3A%2F%2Fmastodon.social&style=social
)](
https://mastodon.social/@rzr/103448015175182101#:pinball:
)
[![snap](
https://snapcraft.io/pinball/badge.svg
)](
https://snapcraft.io/pinball
)
[![IRC Channel](
https://img.shields.io/badge/chat-on%20libera-brightgreen.svg
)](
https://kiwiirc.com/client/irc.libera.chat/#iot
)

## INTRODUCTION ##

Emilia Pinball is a libre pinball game simulator for GNU/Linux.

It can be played on a regular computer or a DiY pincab device.

[![pinball-video](
https://raw.githubusercontent.com/rzr/pinball/master/extra/files/screenshot.png
)](
http://pinball.sf.net
"pinball")

More more details check [FAQ](FAQ.md), [BUILD](BUILD.md), [CONTRIBUTING](CONTRIBUTING.md)
or linked resources from:

* <http://pinball.sourceforge.net/>

Send bug reports (after reading faq) and comments to

* <https://sourceforge.net/projects/pinball/>

For latest updates subscribe:

* <https://purl.org/rzr/pinball>

[![Get it from the Snap Store](
https://snapcraft.io/static/images/badges/en/snap-store-black.svg
)](
https://snapcraft.io/pinball
)

## USAGE ##

Control are straightforward using keyboard, 2 mices can be also used

| Event                   | Keyboard (defaults)     | Mouse (or Mice)         |
|-------------------------|-------------------------|-------------------------|
| Flipper L/R             | Shift (L/R)             | Left/Right button       |
| Launch                  | Enter                   | Middle button or (L+R)  |
| Nudge L/R               | Control (L/R)           | (L or R) + M            |
| Nudge                   | Space                   | L + R + M               |
| Menu                    | Esc                     |                         |
| Reset                   | R                       |                         |

## DEMO ##

[![pinball-video](
https://diode.zone/lazy-static/previews/b764fc94-b455-45f5-a62a-24ec6131112e.jpg
)](
https://rzr.github.io/rzr-presentations/docs/pinball/#/13
"pinball")

Watch video at:

* <https://peertube.debian.social/videos/watch/c23f0709-4099-4302-b877-f7d2562b2880?start=11m26s#:my-diy-pinball-on-debian-2020-rzr>

## RESOURCES ##

* <http://pinball.sf.net/>
* <https://purl.org/rzr/pinball>
* <https://github.com/rzr/pinball/>
* <https://rzr.github.io/rzr-presentations/docs/pincab>
* <https://rzr.github.io/rzr-presentations/docs/pinball>
* <https://purl.org/rzr/presentations>
* <https://purl.org/rzr>
* <https://rzr.github.io/rzr-presentations/docs/pinball/>
* <https://mdco2.mini.debconf.org/talks/23-my-diy-pinball-on-debian/>
* <https://peertube.debian.social/videos/watch/c23f0709-4099-4302-b877-f7d2562b2880#my-diy-pinball-on-debian>
* <https://github.com/rzr/pinball-table-gnu/>
* <https://github.com/rzr/pinball-table-hurd/>
* <https://packages.qa.debian.org/p/pinball.html>
* <https://snapcraft.io/pinball>
* <https://libregamewiki.org/Emilia_Pinball>
* <http://rzr.online.fr/game.htm>
* <https://pdb.finkproject.org/pdb/package.php/pinball>
* <https://aur.archlinux.org/packages/pinball/>
* <https://www.pincabpassion.net/t12916-wip-pincab-libre-sous-gnu-linux-avec-emilia-pinball#210037>
